@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Pod::Weaver::PluginBundle::Default;
 {
-  $Pod::Weaver::PluginBundle::Default::VERSION = '3.101638';
+  $Pod::Weaver::PluginBundle::Default::VERSION = '3.101639';
 }
 # ABSTRACT: a bundle for the most commonly-needed prep work for a pod document
 
@@ -39,6 +39,7 @@ sub mvp_bundle_config {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -47,7 +48,7 @@ Pod::Weaver::PluginBundle::Default - a bundle for the most commonly-needed prep
 
 =head1 VERSION
 
-version 3.101638
+version 3.101639
 
 =head1 OVERVIEW
 
@@ -74,6 +75,9 @@ It is nearly equivalent to the following:
   [Collect / METHODS]
   command = method
 
+  [Collect / FUNCTIONS]
+  command = func
+
   [Leftovers]
 
   [Region  / postlude]
@@ -87,10 +91,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
